@@ -1,12 +1,14 @@
-from xdg import XDG_CONFIG_HOME
 from collections.abc import MutableMapping
 from pathlib import Path
 from typing import Any, cast, Final, Iterator, Literal, TypedDict
-import yaml
+import yaml, os
 
 ConfigKey = Literal["org"]
 
 
+XDG_CONFIG_HOME = os.getenv("XDG_CONFIG_HOME", Path.home() / ".config")
+
+
 class ConfigSchema(TypedDict, total=False):
     org: str
 
